Generic component editor scenes.
Constants
- COMPONENT_
EDITOR_ INVALID_ VALUE_ FIXTURE - Fixture name for a component descriptor holding an invalid value.
- COMPONENT_
EDITOR_ MANY_ PARAM_ FIXTURE - Fixture name for a component descriptor carrying many parameters.
- COMPONENT_
EDITOR_ NO_ PARAM_ FIXTURE - Fixture name for a component descriptor with no parameters.
- COMPONENT_
EDITOR_ TRACE_ ONLY_ FIXTURE - Fixture name for a component descriptor that only carries a trace.
- COMPONENT_
EDITOR_ VIEW_ ID - Stable lens id for the generic component editor.
Functions
- component_
editor_ fixture - Returns the descriptor for the named editor fixture, if it exists.
- component_
editor_ fixture_ names - Returns the names of the built-in component editor fixtures.
- component_
editor_ snapshot - Renders the named fixture into a component editor Scene snapshot.
- component_
editor_ view - Builds the component editor Scene from a component descriptor.