pub fn apply_set_param(params: &Expr, intent: &Expr) -> Result<Expr>
Apply an intent/set-param to a parameter map, returning the new map. The returned value is the operation to commit through realize.
intent/set-param
realize