Module stream

Module stream 

Stream inspector Scene builders.

Constants

STREAM_DETAIL_VIEW_ID
Stable lens id for the single-stream detail view.
STREAM_DIAGNOSTIC_TIMELINE_VIEW_ID
Stable lens id for the stream diagnostic timeline.
STREAM_LIST_VIEW_ID
Stable lens id for the stream list view.
STREAM_PACKET_PREVIEW_VIEW_ID
Stable lens id for the stream packet preview table.

Functions

stream_detail_view
Builds the detail Scene for a single stream snapshot.
stream_diagnostic_timeline_view
Builds the diagnostic timeline Scene for a stream snapshot.
stream_list_view
Builds the stream list Scene from inspector snapshots.
stream_packet_preview_view
Builds the packet preview table Scene from stream items.