Module component

Module component 

Generic component editor scenes.

Constants

COMPONENT_EDITOR_INVALID_VALUE_FIXTURE
Fixture name for a component descriptor holding an invalid value.
COMPONENT_EDITOR_MANY_PARAM_FIXTURE
Fixture name for a component descriptor carrying many parameters.
COMPONENT_EDITOR_NO_PARAM_FIXTURE
Fixture name for a component descriptor with no parameters.
COMPONENT_EDITOR_TRACE_ONLY_FIXTURE
Fixture name for a component descriptor that only carries a trace.
COMPONENT_EDITOR_VIEW_ID
Stable lens id for the generic component editor.

Functions

component_editor_fixture
Returns the descriptor for the named editor fixture, if it exists.
component_editor_fixture_names
Returns the names of the built-in component editor fixtures.
component_editor_snapshot
Renders the named fixture into a component editor Scene snapshot.
component_editor_view
Builds the component editor Scene from a component descriptor.