pub fn apply_scrub(transport: &Expr, intent: &Expr) -> Result<Expr>
Apply an intent/scrub to a transport value, returning the new transport with its playhead moved to the requested position.
intent/scrub